@@ -1261,15 +1261,15 @@ END
       "./script/adventrest_create.pl model TheSchwartz",'__display__');
    $ad='__PACKAGE__->config( class => "TheSchwartz" );%NL%%NL%'. # %NL% is newline
       'sub mangle_arguments { %{ $_[1]->{args} } }%NL%';
-print "LINE 1264\n":
+print "LINE 1264\n";
    ($stdout,$stderr)=$handle->cmd(
       "${sudo}sed -i \'/Catalyst::Model/a$ad\' ".
       "./lib/AdventREST/Model/TheSchwartz.pm");
-print "LINE 1265\n":
+print "LINE 1265\n";
    ($stdout,$stderr)=$handle->cmd( # bash shell specific
       "${sudo}sed -i \'s/%NL%/\'\"`echo \\\\\\n`/g\" ".
       "./lib/AdventREST/Model/TheSchwartz.pm");
-print "LINE 1266\n":
+print "LINE 1266\n";
    $content=<<END;
 Model::TheSchwartz:
   args:
@@ -1277,7 +1277,7 @@ Model::TheSchwartz:
     databases:
       - dsn: dbi:SQLite:__path_to(db/theschwartz.sqlt)__
 END
-print "LINE 1267\n":
+print "LINE 1267\n";
    ($stdout,$stderr)=$handle->cmd("echo \"$content\" >> adventrest.yml");
 print "LINE 1268\n":
    $ad="use Net::FullAuto;%NL%".
@@ -1485,26 +1485,26 @@ print "LINE 1268\n":
        "   setpgrp(0,0) unless \$Fork->in_parent;%NL%".
        "%NL%".
        "}%NL%";
-print "LINE 1269\n":
+print "LINE 1269\n";
    ($stdout,$stderr)=$handle->cmd(
       "${sudo}sed -i \'/use Catalyst::ScriptRunner/i$ad\' ".
       "./script/adventrest_server.pl");
-print "LINE 1270\n":
+print "LINE 1270\n";
    ($stdout,$stderr)=$handle->cmd( # bash shell specific
       "${sudo}sed -i \'s/%NL%/\'\"`echo \\\\\\n`/g\" ".
       "./script/adventrest_server.pl");
-print "LINE 1271\n":
+print "LINE 1271\n";
    ($stdout,$stderr)=$handle->cmd("${sudo}sed -i \"s/%SQ%/\'/g\" ".
       "./script/adventrest_server.pl");
-print "LINE 1272\n":
+print "LINE 1272\n";
    ($stdout,$stderr)=$handle->cwd("..");
-print "LINE 1273\n":
+print "LINE 1273\n";
    ($stdout,$stderr)=$handle->put("fullauto.pem");
    ($stdout,$stderr)=$handle->cmd(
       "wget --random-wait --progress=dot ".
       "https://github.com/pangyre/p5-myapp-10in10/archive/master.zip",
       '__display__');
-print "LINE 1274\n":
+print "LINE 1274\n";
    ($stdout,$stderr)=$handle->cmd("unzip master.zip",'__display__');
    ($stdout,$stderr)=$handle->cmd("rm -rvf master.zip",'__display__');
    ($stdout,$stderr)=$handle->cwd("p5-myapp-10in10-master");
